summaryrefslogtreecommitdiffstats
path: root/src/usr/hwpf/hwp
diff options
context:
space:
mode:
authorMatt Ploetz <maploetz@us.ibm.com>2013-09-24 11:03:02 -0500
committerA. Patrick Williams III <iawillia@us.ibm.com>2013-10-12 14:51:14 -0500
commit4e536844c21b0ab7c256e49c63e8e9520c9e1d19 (patch)
tree03fa743c3e3f5c00cf1d44a936a3c92c7673b48c /src/usr/hwpf/hwp
parenteffbdc22da60af7ae67f69005f63a6a6e4db773d (diff)
downloadtalos-hostboot-4e536844c21b0ab7c256e49c63e8e9520c9e1d19.tar.gz
talos-hostboot-4e536844c21b0ab7c256e49c63e8e9520c9e1d19.zip
Hardware Reconfigure loop and Istepdispatcher redesign
Change-Id: Icc037be6b0eac67d1b5196180f8a53f083afa085 RTC: 34055 Reviewed-on: http://gfw160.austin.ibm.com:8080/gerrit/6324 Tested-by: Jenkins Server Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/usr/hwpf/hwp')
-rw-r--r--src/usr/hwpf/hwp/dram_training/dram_training.C4
-rw-r--r--src/usr/hwpf/hwp/slave_sbe/slave_sbe.C2
-rw-r--r--src/usr/hwpf/hwp/start_payload/start_payload.C12
-rw-r--r--src/usr/hwpf/hwp/tod_init/tod_init.C4
4 files changed, 10 insertions, 12 deletions
diff --git a/src/usr/hwpf/hwp/dram_training/dram_training.C b/src/usr/hwpf/hwp/dram_training/dram_training.C
index 728322596..94cac8ee6 100644
--- a/src/usr/hwpf/hwp/dram_training/dram_training.C
+++ b/src/usr/hwpf/hwp/dram_training/dram_training.C
@@ -95,7 +95,7 @@ void* call_host_disable_vddr( void *io_pArgs )
TRACDCOMP( ISTEPS_TRACE::g_trac_isteps_trace, "call_host_disable_vddr entry" );
- if( !INITSERVICE::spLess() )
+ if(INITSERVICE::spBaseServicesEnabled())
{
IStepError l_StepError;
@@ -395,7 +395,7 @@ void* call_host_enable_vddr( void *io_pArgs )
errlHndl_t l_err = NULL;
- if( !INITSERVICE::spLess() )
+ if(INITSERVICE::spBaseServicesEnabled())
{
IStepError l_StepError;
diff --git a/src/usr/hwpf/hwp/slave_sbe/slave_sbe.C b/src/usr/hwpf/hwp/slave_sbe/slave_sbe.C
index 6a114107f..9ad71dae4 100644
--- a/src/usr/hwpf/hwp/slave_sbe/slave_sbe.C
+++ b/src/usr/hwpf/hwp/slave_sbe/slave_sbe.C
@@ -205,7 +205,7 @@ void* call_host_sbe_start( void *io_pArgs )
// we are just checking the Slave SBE's, skip the master
continue;
}
- else if (INITSERVICE::spLess())
+ else if (!INITSERVICE::spBaseServicesEnabled())
{
//Need to issue SBE start workaround on all slave chips
// Invoke the HWP
diff --git a/src/usr/hwpf/hwp/tod_init/tod_init.C b/src/usr/hwpf/hwp/tod_init/tod_init.C
index 0140d17ff..3f7ea8290 100644
--- a/src/usr/hwpf/hwp/tod_init/tod_init.C
+++ b/src/usr/hwpf/hwp/tod_init/tod_init.C
@@ -52,7 +52,7 @@ void * call_tod_setup(void *dummy)
{
errlHndl_t l_errl;
- if (INITSERVICE::spLess())
+ if (!INITSERVICE::spBaseServicesEnabled())
{
l_errl = TodSvc::getTheInstance().todSetup();
@@ -70,7 +70,7 @@ void * call_tod_init(void *dummy)
{
errlHndl_t l_errl;
- if (INITSERVICE::spLess())
+ if (!INITSERVICE::spBaseServicesEnabled())
{
l_errl = TodSvc::getTheInstance().todInit();
OpenPOWER on IntegriCloud
diff --git a/src/usr/hwpf/hwp/start_payload/start_payload.C b/src/usr/hwpf/hwp/start_payload/start_payload.C
index 86f0e39c5..0d9031da8 100644
--- a/src/usr/hwpf/hwp/start_payload/start_payload.C
+++ b/src/usr/hwpf/hwp/start_payload/start_payload.C
@@ -276,11 +276,10 @@ void* call_host_runtime_setup( void *io_pArgs )
break;
}
- if( is_sapphire_load() &&
- INITSERVICE::spLess())
+ if( is_sapphire_load() && (!INITSERVICE::spBaseServicesEnabled()) )
{
// Write the devtree out when in SPLess
// Sapphire mode
l_err = DEVTREE::build_flatdevtree();
if ( l_err )
{
@@ -541,9 +540,8 @@ errlHndl_t callShutdown ( void )
break;
}
- // Load payload data if in SPLess SAPPHIRE mode
- if( is_sapphire_load() &&
- INITSERVICE::spLess())
+ // Load payload data in Sapphire mode when SP Base Services not enabled
+ if( is_sapphire_load() && (!INITSERVICE::spBaseServicesEnabled()) )
{
payloadData = DEVTREE::get_flatdevtree_phys_addr();
}
@@ -276,11 +276,10 @@ void* call_host_runtime_setup( void *io_pArgs )
{
- // Write the devtree out when in SPLess
- // Sapphire mode
+ // Write the devtree out in Sapphire mode when SP Base Services not
+ // enabled
l_err = DEVTREE::build_flatdevtree();
if ( l_err )